@@ -127,7 +127,7 @@ sub build ( $self ) {
     local *{"$self->{package}\::api"} = \$api;
 
     # "cdn" resolver
-    local ${"$self->{package}\::cdn"} = $self->{app}->{app}->{cdn};
+    local ${"$self->{package}\::cdn"} = $self->{app}->{cdn};
 
     # "l10n" resolver
     local *{"$self->{package}\::l10n"} = sub : prototype($;$$) ( $msgid, $msgid_plural = undef, $num = undef ) {
