@@ -47,47 +47,49 @@ JS
 JS
 
         onSetSrc => func ['src'], <<'JS',
-            var me = this,
-                scale = this.getView().getScale(),
-                el = me.getView().innerElement.dom,
-                loadingTask = pdfjsLib.getDocument(src);
+                var me = this,
+                    scale = this.getView().getScale(),
+                    el = me.getView().innerElement.dom,
+                    loadingTask = pdfjsLib.getDocument(src);
 
-            el.innerHTML = '';
+                el.innerHTML = '';
 
-            loadingTask.promise.then( function(pdf) {
-                var numPages = pdf.numPages,
-                    container = document.createElement("div");
+                loadingTask.promise.then( function(pdf) {
+                    var numPages = pdf.numPages,
+                        container = document.createElement("div");
 
-                container.setAttribute("style", "display:flex;flex-direction:column;justify-content:flex-start;text-align:center;width:100%;");
-                el.appendChild(container);
+                    container.setAttribute("style", "display:flex;flex-direction:column;justify-content:flex-start;text-align:center;width:100%;");
+                    el.appendChild(container);
 
-                for ( var i = 1; i <= numPages; i++ ) {
+                    for ( var i = 1; i <= numPages; i++ ) {
 
-                    // fetch page
-                    pdf.getPage(i).then( function(page) {
-                        var viewport = page.getViewport(scale);
+                        // fetch page
+                        pdf.getPage(i).then( function(page) {
+                            var viewport = page.getViewport(scale);
 
-                        // Prepare canvas using PDF page dimensions
-                        var div = document.createElement("div");
-                        container.appendChild(div);
+                            // Prepare canvas using PDF page dimensions
+                            var div = document.createElement("div");
+                            container.appendChild(div);
 
-                        var canvas = document.createElement("canvas");
-                        div.appendChild(canvas);
+                            var canvas = document.createElement("canvas");
+                            div.appendChild(canvas);
 
-                        var context = canvas.getContext('2d');
-                        canvas.height = viewport.height;
-                        canvas.width = viewport.width;
+                            var context = canvas.getContext('2d');
+                            canvas.height = viewport.height;
+                            canvas.width = viewport.width;
 
-                        // Render PDF page into canvas context
-                        var renderContext = {
-                            canvasContext: context,
-                            viewport: viewport,
-                        };
+                            // Render PDF page into canvas context
+                            var renderContext = {
+                                canvasContext: context,
+                                viewport: viewport,
+                            };
 
-                        page.render(renderContext);
-                    });
-                }
-            });
+                            page.render(renderContext);
+                        });
+                    }
+                }).catch(function (error) {
+                    alert(error.message);
+                });
 JS
     };
 }
